@@ -17,6 +17,18 @@ linux-2.6.38/drivers/i2c/busses/i2c-i801.c
 #include "langford.h"
 
 
+// NOTE: Linux kernel commit 63a29f744fe1c19742039ce7526663a98f172f7e removes
+// the use of __dev (and __devinit, __devexit_p, __devinitdata, _devinitconst,
+// and __devexit from ther kernel because CONFIG_HOTPLUG is going away.
+//
+// To address this, we redefine these functions for kernels 3.8+
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,8,0)
+#define __devinit
+#define __devexit
+#define __devexit_p(x) x
+#endif
+
 static DevPrivDataType	*DevPrivData;
 
 /*Character device data structures*/
